@@ -19,3 +19,5 @@
 
 /// Current version of pallet Ethereum's storage schema is stored under this key.
 pub const PALLET_ETHEREUM_SCHEMA: &'static [u8] = b":ethereum_schema";
+/// Cached version of pallet Ethereum's storage schema is stored under this key in the AuxStore.
+pub const PALLET_ETHEREUM_SCHEMA_CACHE: &'static [u8] = b":ethereum_schema_cache";
